@@ -28,8 +28,6 @@
 
 #include "qpol_internal.h"
 #include <assert.h>
-#include <byteswap.h>
-#include <endian.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <limits.h>
@@ -37,7 +35,15 @@
 #include <stdlib.h>
 #include <sys/mman.h>
 #include <sys/stat.h>
-#include <asm/types.h>
+
+#ifdef DARWIN
+# include <qpol/linux_types.h>
+# include <machine/endian.h>
+# include <sys/types.h>
+#else
+# include <endian.h>
+# include <asm/types.h>
+#endif
 
 #include <sepol/debug.h>
 #include <sepol/handle.h>
@@ -380,13 +386,6 @@ int qpol_is_file_mod_pkg(FILE * fp)
 static int infer_policy_version(qpol_policy_t * policy)
 {
 	policydb_t *db = NULL;
-	const qpol_class_t *obj_class = NULL;
-	qpol_iterator_t *iter = NULL;
-	qpol_fs_use_t *fsuse = NULL;
-	qpol_range_trans_t *rangetrans = NULL;
-	uint32_t behavior = 0;
-	size_t nvtrans = 0, fsusexattr = 0;
-	const char *obj_name = NULL;
 
 	if (!policy) {
 		ERR(policy, "%s", strerror(EINVAL));
@@ -401,139 +400,11 @@ static int infer_policy_version(qpol_policy_t * policy)
 		return STATUS_SUCCESS;
 	}
 
-	/* check fs_use for xattr and psid */
-	qpol_policy_get_fs_use_iter(policy, &iter);
-	for (; !qpol_iterator_end(iter); qpol_iterator_next(iter)) {
-		qpol_iterator_get_item(iter, (void **)&fsuse);
-		qpol_fs_use_get_behavior(policy, fsuse, &behavior);
-		/* not possible to have xattr and psid in same policy */
-		if (behavior == QPOL_FS_USE_XATTR) {
-			fsusexattr = 1;
-			break;
-		} else if (behavior == QPOL_FS_USE_PSID) {
-			qpol_iterator_destroy(&iter);
-			db->policyvers = 12;
-			return STATUS_SUCCESS;
-		}
-	}
-	qpol_iterator_destroy(&iter);
-
-/* Check each version change from 30 to 24 */
-/* If these are available set version 30 */
-#if defined(HAVE_SEPOL_XPERM_IOCTL) || defined(HAVE_SEPOL_XEN_DEVICETREE)
-	db->policyvers = 30;
-	return STATUS_SUCCESS;
-#endif
-
-/* If this is available then set version 29 */
-#ifdef HAVE_SEPOL_CONSTRAINT_NAMES
-	db->policyvers = 29;
-	return STATUS_SUCCESS;
-#endif
-
-/*
- * These will remove the rules from policy_define.c if libsepol
- * does not have the support listed in policydb.h. The earlier code
- * checked for at least one rule before enabling - this patch does not
- * as if in policydb.h then must be capable of being built.
- */
-#ifdef HAVE_SEPOL_DEFAULT_TYPE
-	db->policyvers = 28;
-	return STATUS_SUCCESS;
-#endif
-
-#ifdef HAVE_SEPOL_NEW_OBJECT_DEFAULTS
-	db->policyvers = 27;
-	return STATUS_SUCCESS;
-#endif
-
-/* This seems to be in place already ??
-#ifdef HAVE_SEPOL_ROLETRANS
-	db->policyvers = 26;
-	return STATUS_SUCCESS;
-#endif */
-
-#ifdef HAVE_SEPOL_FILENAME_TRANS
-	db->policyvers = 25;
-	return STATUS_SUCCESS;
-#endif
-
-#ifdef HAVE_SEPOL_BOUNDARY
-	db->policyvers = 24;
-	return STATUS_SUCCESS;
-#endif
-
-#if defined(HAVE_SEPOL_PERMISSIVE_TYPES) || defined(HAVE_SEPOL_POLICYCAPS)
-	ebitmap_node_t *node = NULL;
-	unsigned int i = 0;
-#endif
-
-	/* 23 : there exists at least one type that is permissive */
-#ifdef HAVE_SEPOL_PERMISSIVE_TYPES
-	ebitmap_for_each_bit(&db->permissive_map, node, i) {
-		if (ebitmap_get_bit(&db->permissive_map, i)) {
-			db->policyvers = 23;
-			return STATUS_SUCCESS;
-		}
-	}
-#endif
-
-	/* 22 : there exists at least one policy capability */
-#ifdef HAVE_SEPOL_POLICYCAPS
-	ebitmap_for_each_bit(&db->policycaps, node, i) {
-		if (ebitmap_get_bit(&db->policycaps, i)) {
-			db->policyvers = 22;
-			return STATUS_SUCCESS;
-		}
-	}
-#endif
-
-	/* 21 : object classes other than process for range_transitions */
-	qpol_policy_get_range_trans_iter(policy, &iter);
-	for (; !qpol_iterator_end(iter); qpol_iterator_next(iter)) {
-		qpol_iterator_get_item(iter, (void **)&rangetrans);
-		qpol_range_trans_get_target_class(policy, rangetrans, &obj_class);
-		qpol_class_get_name(policy, obj_class, &obj_name);
-		if (strcmp(obj_name, "process")) {
-			db->policyvers = 21;
-			qpol_iterator_destroy(&iter);
-			return STATUS_SUCCESS;
-		}
-	}
-	qpol_iterator_destroy(&iter);
-
-	/* 19 & 20 : mls and validatetrans statements added */
-	qpol_policy_get_validatetrans_iter(policy, &iter);
-	qpol_iterator_get_size(iter, &nvtrans);
-	qpol_iterator_destroy(&iter);
-	if (db->mls || nvtrans) {
-		db->policyvers = 19;
-	}
-
-	/* 18 : the netlink_audit_socket class added */
-	else if (hashtab_search(db->p_classes.table, (hashtab_key_t)"netlink_audit_socket")) {
-		db->policyvers = 18;
-	}
-
-	/* 17 : IPv6 nodecon statements added */
-	else if (db->ocontexts[OCON_NODE6]) {
-		db->policyvers = 17;
-	}
-
-	/* 16 : conditional policy added */
-	else if (db->p_bool_val_to_name && db->p_bool_val_to_name[0]) {
-		db->policyvers = 16;
-
-	}
-	/* 15 */
-	else if (fsusexattr) {
-		db->policyvers = 15;
-	}
-
-	/* 12 */
-	else {
-		db->policyvers = 12;
-	}
+	/* Do not try to infer policy version, as it is
+	 * a compile-time setting, and the policy can
+	 * be downgraded.
+	 */
+	db->policyvers = POLICYDB_VERSION_MAX;
 
 	return STATUS_SUCCESS;
 }
@@ -775,19 +646,6 @@ err:
 	return 1;
 }
 
-/* forward declarations see policy_extend.c */
-struct qpol_extended_image;
-extern void qpol_extended_image_destroy(struct qpol_extended_image **ext);
-
-#if LINK_SHARED == 1
-__asm__(".symver qpol_policy_open_from_file_old,qpol_policy_open_from_file@");
-__asm__(".symver qpol_policy_open_from_file_opt,qpol_policy_open_from_file@@VERS_1.3");
-__asm__(".symver qpol_policy_open_from_memory_old,qpol_policy_open_from_memory@");
-__asm__(".symver qpol_policy_open_from_memory_opt,qpol_policy_open_from_memory@VERS_1.3");
-__asm__(".symver qpol_policy_rebuild_old,qpol_policy_rebuild@");
-__asm__(".symver qpol_policy_rebuild_opt,qpol_policy_rebuild@@VERS_1.3");
-#endif
-
 /**
  * @brief Internal version of qpol_policy_rebuild() version 1.3
  *
@@ -795,7 +653,7 @@ __asm__(".symver qpol_policy_rebuild_opt,qpol_policy_rebuild@@VERS_1.3");
  * for version 1.3; this symbol name is not exported.
  * @see qpol_policy_rebuild()
  */
-int qpol_policy_rebuild_opt(qpol_policy_t * policy, const int options)
+int qpol_policy_rebuild(qpol_policy_t * policy, const int options)
 {
 	sepol_policydb_t *old_p = NULL;
 	sepol_policydb_t **modules = NULL;
@@ -820,8 +678,6 @@ int qpol_policy_rebuild_opt(qpol_policy_t * policy, const int options)
 	/* cache old policy in case of failure */
 	old_p = policy->p;
 	policy->p = NULL;
-	struct qpol_extended_image *ext = policy->ext;
-	policy->ext = NULL;
 	old_options = policy->options;
 	policy->options = options;
 
@@ -912,7 +768,6 @@ int qpol_policy_rebuild_opt(qpol_policy_t * policy, const int options)
 		error = errno;
 		goto err;
 	}
-	qpol_extended_image_destroy(&ext);
 
 	sepol_policydb_free(old_p);
 
@@ -922,45 +777,11 @@ int qpol_policy_rebuild_opt(qpol_policy_t * policy, const int options)
 	free(modules);
 
 	policy->p = old_p;
-	policy->ext = ext;
 	policy->options = old_options;
 	errno = error;
 	return STATUS_ERR;
 }
 
-#if LINK_SHARED == 0
-int qpol_policy_rebuild(qpol_policy_t * policy, int options)
-{
-	return qpol_policy_rebuild_opt(policy, options);
-}
-#endif
-
-/**
- * @brief Internal version of qpol_policy_rebuild() version 1.2 or earlier
- * @deprecated use the 1.3 version.
- * @see qpol_policy_rebuild()
- */
-int qpol_policy_rebuild_old(qpol_policy_t * policy)
-{
-	if (!policy) {
-		ERR(NULL, "%s", strerror(EINVAL));
-		errno = EINVAL;
-		return STATUS_ERR;
-	}
-
-	/* fail if not a modular policy */
-	if (policy->type != QPOL_POLICY_MODULE_BINARY) {
-		ERR(policy, "%s", strerror(ENOTSUP));
-		errno = ENOTSUP;
-		return STATUS_ERR;
-	}
-
-	if (!policy->modified)
-		return STATUS_SUCCESS;
-
-	return qpol_policy_rebuild_opt(policy, policy->options);
-}
-
 /**
  * @brief Internal version of qpol_policy_open_from_file() version 1.3
  *
@@ -968,7 +789,7 @@ int qpol_policy_rebuild_old(qpol_policy_t * policy)
  * for version 1.3; this symbol name is not exported.
  * @see qpol_policy_open_from_file()
  */
-int qpol_policy_open_from_file_opt(const char *path, qpol_policy_t ** policy, qpol_callback_fn_t fn, void *varg, const int options)
+int qpol_policy_open_from_file(const char *path, qpol_policy_t ** policy, qpol_callback_fn_t fn, void *varg, const int options)
 {
 	int error = 0, retv = -1;
 	FILE *infile = NULL;
@@ -1057,7 +878,7 @@ int qpol_policy_open_from_file_opt(const char *path, qpol_policy_t ** policy, qp
 		}
 		/* *policy now owns mod */
 		mod = NULL;
-		if (qpol_policy_rebuild_opt(*policy, options)) {
+		if (qpol_policy_rebuild(*policy, options)) {
 			error = errno;
 			goto err;
 		}
@@ -1146,18 +967,6 @@ int qpol_policy_open_from_file_opt(const char *path, qpol_policy_t ** policy, qp
 	return -1;
 }
 
-#if LINK_SHARED == 0
-int qpol_policy_open_from_file(const char *path, qpol_policy_t ** policy, qpol_callback_fn_t fn, void *varg, const int options)
-{
-	return qpol_policy_open_from_file_opt(path, policy, fn, varg, options);
-}
-#endif
-
-int qpol_policy_open_from_file_no_rules(const char *path, qpol_policy_t ** policy, qpol_callback_fn_t fn, void *varg)
-{
-	return qpol_policy_open_from_file_opt(path, policy, fn, varg, QPOL_POLICY_OPTION_NO_RULES);
-}
-
 /**
  * @brief Internal version of qpol_policy_open_from_memory() version 1.3
  *
@@ -1165,7 +974,7 @@ int qpol_policy_open_from_file_no_rules(const char *path, qpol_policy_t ** polic
  * for version 1.3; this symbol name is not exported.
  * @see qpol_policy_open_from_memory()
  */
-int qpol_policy_open_from_memory_opt(qpol_policy_t ** policy, const char *filedata, size_t size, qpol_callback_fn_t fn, void *varg,
+int qpol_policy_open_from_memory(qpol_policy_t ** policy, const char *filedata, size_t size, qpol_callback_fn_t fn, void *varg,
 				     const int options)
 {
 	int error = 0;
@@ -1258,40 +1067,11 @@ int qpol_policy_open_from_memory_opt(qpol_policy_t ** policy, const char *fileda
 
 }
 
-#if LINK_SHARED == 0
-int qpol_policy_open_from_memory(qpol_policy_t ** policy, const char *filedata, size_t size, qpol_callback_fn_t fn, void *varg,
-				 const int options)
-{
-	return qpol_policy_open_from_memory_opt(policy, filedata, size, fn, varg, options);
-}
-#endif
-
-/**
- * @brief Internal version of qpol_policy_open_from_file() version 1.2 or earlier
- * @deprecated use the 1.3 version.
- * @see qpol_policy_open_from_file()
- */
-int qpol_policy_open_from_file_old(const char *path, qpol_policy_t ** policy, qpol_callback_fn_t fn, void *varg)
-{
-	return qpol_policy_open_from_file(path, policy, fn, varg, 0);
-}
-
-/**
- * @brief Internal version of qpol_policy_open_from_memory() version 1.2 or earlier
- * @deprecated use the 1.3 version.
- * @see qpol_policy_open_from_memory()
- */
-int qpol_policy_open_from_memory_old(qpol_policy_t ** policy, const char *filedata, size_t size, qpol_callback_fn_t fn, void *varg)
-{
-	return qpol_policy_open_from_memory_opt(policy, filedata, size, fn, varg, 0);
-}
-
 void qpol_policy_destroy(qpol_policy_t ** policy)
 {
 	if (policy != NULL && *policy != NULL) {
 		sepol_policydb_free((*policy)->p);
 		sepol_handle_destroy((*policy)->sh);
-		qpol_extended_image_destroy(&((*policy)->ext));
 		if ((*policy)->modules) {
 			size_t i = 0;
 			for (i = 0; i < (*policy)->num_modules; i++) {
